@@ -152,6 +152,37 @@ class Mine:
 
         return response
 
+    @staticmethod
+    def get_identifiers():
+        """
+        Call the get_identifiers endpoint
+
+        :return: the result return list of identifiers and file ids
+        """
+
+        url = f'{Config.host}/search'
+        payload = {
+            'q': '*'
+        }
+
+        result = requests.get(url, params=payload)
+
+        # Parse the result using Elasticsearch Response
+        result = Response(Search(), result.json())
+
+        response = []
+        for hit in result.hits:
+            identifier = {}
+            files = hit['origin']['files']
+            for file in files:
+                for k in hit['mine']['dc_identifier']:
+                    identifier['identifier'] = hit['mine']['dc_identifier'][k]
+                    break
+                identifier['file_id'] = file['id']
+                response.append(identifier)
+
+        return response
+
     @property
     def host(self):
         return self._host
